## Abstract Base Class

::: prob_conf_mat.metrics.abc.Averaging
    options:
        heading_level: 3
        members:
            - "dependencies"
            - "sklearn_equivalent"
            - "aliases"
            - "compute_average"

## Metric Instances

::: prob_conf_mat.metrics.averaging.MacroAverage
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - dependencies
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics.averaging.WeightedAverage
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - dependencies
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics.averaging.SelectPositiveClass
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - dependencies
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics.averaging.HarmonicMean
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - dependencies
                - sklearn_equivalent
        show_labels: false
        group_by_category: false

::: prob_conf_mat.metrics.averaging.GeometricMean
    options:
        heading_level: 3
        show_root_heading: true
        show_root_toc_entry: true
        show_category_heading: false
        show_symbol_type_toc: true
        summary:
                attributes: false
                functions: false
                modules: false
        members:
                - aliases
                - dependencies
                - sklearn_equivalent
        show_labels: false
        group_by_category: false
